@@ -16,10 +16,11 @@
 #include "jit/BaselineFrame.h"   // js::jit::BaselineFrame
 #include "jit/JitFrames.h"       // js::jit::EnsureUnwoundJitExitFrame
 #include "jit/JSJitFrameIter.h"  // js::jit::{FrameType,InlineFrameIterator,JSJitFrameIter,MaybeReadFallback,SnapshotIterator}
-#include "js/GCAPI.h"            // JS::AutoSuppressGCAnalysis
-#include "js/Principals.h"       // JSSubsumesOp
-#include "js/RootingAPI.h"       // JS::Rooted
-#include "vm/Activation.h"       // js::Activation{,Iterator}
+#include "js/ColumnNumber.h"  // JS::LimitedColumnNumberOneOrigin, JS::TaggedColumnNumberOneOrigin
+#include "js/GCAPI.h"              // JS::AutoSuppressGCAnalysis
+#include "js/Principals.h"         // JSSubsumesOp
+#include "js/RootingAPI.h"         // JS::Rooted
+#include "vm/Activation.h"         // js::Activation{,Iterator}
 #include "vm/EnvironmentObject.h"  // js::CallObject
 #include "vm/JitActivation.h"      // js::jit::JitActivation
 #include "vm/JSContext.h"          // JSContext
@@ -123,7 +124,12 @@ JS::Realm* JitFrameIter::realm() const {
     return asWasm().instance()->realm();
   }
 
-  return asJSJit().script()->realm();
+  if (asJSJit().isScripted()) {
+    return asJSJit().script()->realm();
+  }
+
+  MOZ_RELEASE_ASSERT(asJSJit().isTrampolineNative());
+  return asJSJit().callee()->realm();
 }
 
 uint8_t* JitFrameIter::resumePCinCurrentFrame() const {
@@ -568,7 +574,7 @@ JSAtom* FrameIter::maybeFunctionDisplayAtom() const {
         return wasmFrame().functionDisplayAtom();
       }
       if (isFunctionFrame()) {
-        return calleeTemplate()->displayAtom();
+        return calleeTemplate()->fullDisplayAtom();
       }
       return nullptr;
   }
@@ -618,7 +624,7 @@ const char16_t* FrameIter::displayURL() const {
   MOZ_CRASH("Unexpected state");
 }
 
-unsigned FrameIter::computeLine(uint32_t* column) const {
+unsigned FrameIter::computeLine(JS::TaggedColumnNumberOneOrigin* column) const {
   switch (data_.state_) {
     case DONE:
       break;
@@ -627,7 +633,12 @@ unsigned FrameIter::computeLine(uint32_t* column) const {
       if (isWasm()) {
         return wasmFrame().computeLine(column);
       }
-      return PCToLineNumber(script(), pc(), column);
+      JS::LimitedColumnNumberOneOrigin columnNumber;
+      unsigned lineNumber = PCToLineNumber(script(), pc(), &columnNumber);
+      if (column) {
+        *column = JS::TaggedColumnNumberOneOrigin(columnNumber);
+      }
+      return lineNumber;
   }
 
   MOZ_CRASH("Unexpected state");
@@ -772,7 +783,7 @@ void FrameIter::wasmUpdateBytecodeOffset() {
 
   // Relookup the current frame, updating the bytecode offset in the process.
   data_.jitFrames_ = JitFrameIter(data_.activations_->asJit());
-  while (wasmFrame().debugFrame() != frame) {
+  while (!isWasm() || wasmFrame().debugFrame() != frame) {
     ++data_.jitFrames_;
   }
 
